@@ -7,6 +7,7 @@ import Lightning from '@site/static/assets/feature-icons/lightning.svg';
 import Palette from '@site/static/assets/feature-icons/palette.svg';
 import FontLigatures from '@site/static/assets/feature-icons/font-ligatures.svg';
 import Splits from '@site/static/assets/feature-icons/splits.svg';
+import CustomShaders from '@site/static/assets/feature-icons/custom-shaders.svg';
 
 /**
  * @satisfies {import('@site/src/components/FeaturesSection/index').FeatureCardProps[]}
@@ -80,12 +81,24 @@ const FEATURES = [
   {
     title: translate({
       message: 'Splits',
-      id: 'home.features.font-ligatures.title',
+      id: 'home.features.splits.title',
     }),
     Icon: Splits,
     description: (
-      <Translate id="home.features.font-ligatures.description">
-        Support to split and manage terminal screens in any platform that you would want to. 
+      <Translate id="home.features.splits.description">
+        Support to split and manage terminal screens in any platform that you would want to.
+      </Translate>
+    ),
+  },
+  {
+    title: translate({
+      message: 'RetroArch shaders',
+      id: 'home.features.custom-shaders.title',
+    }),
+    Icon: CustomShaders,
+    description: (
+      <Translate id="home.features.custom-shaders.description">
+        Rio support configure custom filters and CRT shaders through RetroArch shader files.
       </Translate>
     ),
   },
